import { Address, ChainEntity, ChainEntityBase, ChainKey, Change, Changed, Created, EntityFilter, Info, Person, TableFilter } from '@yukawa/chain-base-angular-domain';
import { Account } from '@yukawa/chain-security-angular-core';
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.group.Group <br/>
*/
export interface Group extends ChainEntityBase, Created {
    change?: Change;
    created?: Change;
    info?: Info;
    /**
    *	@example users
    */
    name: string;
    /**
    *	@example all
    */
    parentId?: string;
    roles: string[];
    /**
    *	@example system
    */
    type?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.group.GroupFilter <br/>
*/
export interface GroupFilter extends EntityFilter {
    /**
    *	@example ADMINS
    */
    groupName?: string;
    /**
    *	@example system
    */
    type?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.org.Org <br/>
*/
export interface Org extends ChainEntity, Changed, Created {
    addresses?: Address[];
    change?: Change;
    /**
    *	@example Yukawa Systems GmbH
    */
    companyName?: string;
    created?: Change;
    /**
    *	@example yukawa@example.com
    */
    email?: string;
    info?: Info;
    /**
    *	@example 100
    */
    orgId?: string;
    /**
    *	@example +49 100 200 300
    */
    phoneNumber?: string;
    /**
    *	@example DE113344
    */
    taxId?: string;
    /**
    *	@example http://yukawa.de/
    */
    website?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.org.OrgFilter <br/>
*/
export interface OrgFilter extends EntityFilter {
    addressFilter?: any;
    companyName?: string;
    email?: string;
    /**
    *	@example 100
    */
    orgId?: string;
    phoneNumber?: string;
    /**
    *	@example DE113344
    */
    taxId?: string;
    website?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.setting.Setting <br/>
*/
export interface Setting extends ChainEntity, Changed, Info {
    change?: Change;
    /**
    *	@example default central storage location
    */
    readonly desc?: string;
    /**
    *	@example main
    */
    module: string;
    /**
    *	@example Central Storage Location
    */
    readonly name?: string;
    /**
    *	@example storage.location.central
    */
    readonly shortName: string;
    /**
    *	@example 1337
    */
    value: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.setting.SettingFilter <br/>
*/
export interface SettingFilter extends EntityFilter {
    /**
    *	@example stock
    */
    module?: string;
    /**
    *	@example storage*
    */
    shortName?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.tag.Tag <br/>
*/
export interface Tag extends ChainEntityBase, Changed {
    change?: Change;
    info: Info;
    readonly key?: ChainKey;
    tagId?: string;
    vocabularyId?: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.tag.TagFilter <br/>
*/
export interface TagFilter extends TableFilter {
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.user.User <br/>
*/
export interface User extends ChainEntity, Changed, Created {
    account: Account;
    change?: Change;
    created?: Change;
    groups?: string[];
    organisationIds?: string[];
    person?: Person;
    /**
    *	@example admin
    */
    username: string;
}
/**
*	@generator rest2ts
*	javaType: inc.yukawa.chain.modules.main.core.domain.user.UserFilter <br/>
*/
export interface UserFilter extends EntityFilter {
    /**
    *	@example admins
    */
    group?: string;
    organisationIds?: string[];
    personFilter?: any;
    /**
    *	@example admin
    */
    username?: string;
}
/**
*	@generator rest2ts
*	tag vocabulary <br/>
*	javaType: inc.yukawa.chain.modules.main.core.domain.tag.Vocabulary <br/>
*/
export interface Vocabulary extends ChainEntityBase, Changed {
    readonly key?: ChainKey;
    vocabularyId?: string;
}
